@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -19,10 +19,14 @@
 #ifndef AutoCorrectionLanguage_H
 #define AutoCorrectionLanguage_H
 
-#include <KComboBox>
+#include <QComboBox>
 #include "pimcommon_export.h"
 
 namespace PimCommon {
+/**
+ * @brief The AutoCorrectionLanguage class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT AutoCorrectionLanguage : public QComboBox
 {
 public:
